var dns = require('native-dns');
var express = require('express');
var util = require('util');
var url = require('url');
var events = require("events");

// cache broken
dns.platform.cache=false;
// ubuntu >= 12.05 -- adjust as needed
var localhost = '127.0.1.1';

var app = express();

app.get ('/', function(req, res){
    "use strict";
    res.type('html');
    res.sendfile('expressDNS.html');
});

var getRRC = function getRRC (labelpath, cbfn ) {
    "use strict";
    var cb = cbfn;

    var question = dns.Question({
	name: labelpath,
	type: 'NAPTR'
    });

    var start = new Date().getTime();

    var req = dns.Request({
	question: question,
	server: { address: localhost, port: 53, type: 'tcp' },
	timeout: 1000
    });

    req.on('timeout', function () {
	console.log('Timeout in making request');
    });

    req.on('message', function (err, answer) {
	var each ;
	var result = [];

	answer.answer.forEach(function (a) {
            var sep = '', split = '';
	    var condition = (typeof a.replacement !== 'undefined') && 
		(a.replacement).length > 0;
	     each = { flags : a.flags, 
			 service: a.service, 
			 value : (condition ? a.replacement : a.regexp)  
		       };

            if (!condition && (each.value.length > 0)) {
		sep = each.value.substring(0,1);
                split = each.value.split(sep);
                each.value = split[2];
             }

	    result.push(JSON.stringify(each));

	    console.log(a.flags + ' ' + a.service );
	});

	  cb(result);
    });

    req.on('end', function () {
	var delta = (new Date().getTime()) - start;
	console.log('Finished processing request: ' + delta.toString() + 'ms');
	
    });

    req.send();
};


var EventSynchronizer = function () {
    "use strict";
    events.EventEmitter.call(this);

    var topresult = "";

    this.cbTest = function cbTest(result) {
        topresult = JSON.stringify(result);
	console.log("callback test "+topresult);

    };

    this.start = function start(lb) {
	getRRC(lb, this.cbTest);
    };

    this.startAjaxCaller = function startAjaxCaller(lb,cb) {
	getRRC(lb, cb);
    };
};

util.inherits(EventSynchronizer,events.EventEmitter);


app.get ('/dns', function(req, res){
    "use strict";
    var label  = url.parse(req.url,true).query.label;
    var synchronizer = new EventSynchronizer();
    synchronizer.startAjaxCaller(label, function(dnsresult) {
        console.log(dnsresult);
	res.send(dnsresult);
    });
});
 

app.listen(3003);

// node-side testing object
// var synchronizerTest = new EventSynchronizer();
// synchronizerTest.start("freeswitch.org");
// synchronizerTest.start("0.2.0.1.1.6.5.1.0.3.1.loligo.com.");

